pub struct MessageProof {
pub message_proof: MerkleProof,
pub block_proof: MerkleProof,
pub message_block_header: Header,
pub commit_block_header: Header,
pub sender: Bech32Address,
pub recipient: Bech32Address,
pub nonce: Nonce,
pub amount: u64,
pub data: Vec<u8>,
}Fields
message_proof: MerkleProofProof that message is contained within the provided block header.
block_proof: MerkleProofProof that the provided block header is contained within the blockchain history.
message_block_header: HeaderThe previous fuel block header that contains the message. Message block height < commit block height.
commit_block_header: HeaderThe consensus header associated with the finalized commit being used as the root of the block proof.
sender: Bech32Addressrecipient: Bech32Addressnonce: Nonceamount: u64data: Vec<u8>Trait Implementations
Sourceimpl Debug for MessageProof
impl Debug for MessageProof
Sourceimpl From<MessageProof> for MessageProof
impl From<MessageProof> for MessageProof
Sourcefn from(client_message_proof: ClientMessageProof) -> Self
fn from(client_message_proof: ClientMessageProof) -> Self
Converts to this type from the input type.